@@ -37,8 +37,6 @@ class VerifiedName(TimeStampedModel):
         choices=[(st.value, st.value) for st in VerifiedNameStatus],
         default=VerifiedNameStatus.PENDING.value,
     )
-    # is_verified is being removed
-    is_verified = models.BooleanField(default=False, null=True)
 
     class Meta:
         """ Meta class for this Django model """
